summaryrefslogtreecommitdiffstats
path: root/controller-api
diff options
context:
space:
mode:
authorJon Marius Venstad <jvenstad@yahoo-inc.com>2019-05-08 15:17:26 +0200
committerJon Marius Venstad <jvenstad@yahoo-inc.com>2019-05-09 11:18:39 +0200
commit94850730a44f6ca7a932ab56bc886eac73eefa49 (patch)
tree4856783b04f0b42f9e1cf1a250463e704a84fbbd /controller-api
parent7959eb47094ea185d3ab02d68c5db5091390402d (diff)
Expand ApplicationStore with dev package storage and retrieval
Diffstat (limited to 'controller-api')
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java8
1 files changed, 7 insertions, 1 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java
index 11886f7dd18..426a3a17296 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java
@@ -22,7 +22,7 @@ public interface ApplicationStore {
/** Removes applications older than the given version, for the given application, and returns whether something was removed. */
boolean prune(ApplicationId application, ApplicationVersion olderThanVersion);
/** Removes all application packages for the given application. */
void removeAll(ApplicationId application);
/** Returns the tester application package of the given version. Does NOT contain the services.xml. */
@@ -37,4 +37,10 @@ public interface ApplicationStore {
/** Removes all tester packages for the given tester. */
void removeAll(TesterId tester);
+ /** Stores the given application package as the development package for the given application. */
+ void putDev(ApplicationId application, byte[] applicationPackage);
+
+ /** Returns the development package for the given application. */
+ byte[] getDev(ApplicationId application);
+
}
@@ -22,7 +22,7 @@ public interface ApplicationStore {
/** Removes applications older than the given version, for the given application, and returns whether something was removed. */
boolean prune(ApplicationId application, ApplicationVersion olderThanVersion);
- /** Removes all application packages for the given application. */
+ /** Removes all application packages for the given application, including any development package. */
void removeAll(ApplicationId application);
/** Returns the tester application package of the given version. Does NOT contain the services.xml. */